pub fn validate_and_prepare_time_alert(
name: &str,
alert_time_ns: UnixNanos,
allow_past: Option<bool>,
ts_now: UnixNanos,
) -> Result<(Ustr, UnixNanos)>Expand description
Validates and normalizes parameters for a time alert.
allow_past defaults to true. When enabled, a past alert timestamp is replaced with
ts_now. Returns the interned name and normalized alert timestamp.
Errors
Returns an error if name is invalid or the alert is in the past when past alerts are
disallowed.