ClockApi

Struct ClockApi 

pub struct ClockApi<'a> { /* private fields */ }
User-facing clock API.

Implementations

Source

impl<'a> ClockApi<'a>

pub fn timestamp_ns(&self) -> UnixNanos

Returns the current UNIX nanoseconds timestamp.

Panics

Panics if the clock is already mutably borrowed.

pub fn timestamp_us(&self) -> u64

Returns the current UNIX timestamp in microseconds.

Panics

Panics if the clock is already mutably borrowed.

pub fn timestamp_ms(&self) -> u64

Returns the current UNIX timestamp in milliseconds.

Panics

Panics if the clock is already mutably borrowed.

pub fn timestamp(&self) -> f64

Returns the current UNIX timestamp in seconds.

Panics

Panics if the clock is already mutably borrowed.

pub fn utc_now(&self) -> DateTime<Utc>

Returns the current UTC time.

Panics

Panics if the clock is already mutably borrowed.

pub fn set_time_alert( &self, name: &str, alert_time: DateTime<Utc>, callback: Option<TimeEventCallback>, allow_past: Option<bool>, ) -> Result<()>

Sets a time alert delivered through the actor’s on_time_event callback.

Errors

Returns an error if the alert cannot be scheduled.

Panics

Panics if the clock is already borrowed.

pub fn set_time_alert_ns( &self, name: &str, alert_time_ns: UnixNanos, callback: Option<TimeEventCallback>, allow_past: Option<bool>, ) -> Result<()>

Sets a time alert in UNIX nanoseconds delivered through the actor’s on_time_event callback.

Errors

Returns an error if the alert cannot be scheduled.

Panics

Panics if the clock is already borrowed.

pub fn set_timer( &self, name: &str, interval: Duration, start_time: Option<DateTime<Utc>>, stop_time: Option<DateTime<Utc>>, callback: Option<TimeEventCallback>, allow_past: Option<bool>, fire_immediately: Option<bool>, ) -> Result<()>

Sets a timer delivered through the actor’s on_time_event callback.

Errors

Returns an error if the timer cannot be scheduled.

Panics

Panics if the clock is already borrowed.

pub fn set_timer_ns( &self, name: &str, interval_ns: u64, start_time_ns: Option<UnixNanos>, stop_time_ns: Option<UnixNanos>, callback: Option<TimeEventCallback>, allow_past: Option<bool>, fire_immediately: Option<bool>, ) -> Result<()>

Sets a timer in UNIX nanoseconds delivered through the actor’s on_time_event callback.

Errors

Returns an error if the timer cannot be scheduled.

Panics

Panics if the clock is already borrowed.

pub fn timer_names(&self) -> Vec<String>

Returns active timer names.

Panics

Panics if the clock is already mutably borrowed.

pub fn timer_count(&self) -> usize

Returns the count of active timers.

Panics

Panics if the clock is already mutably borrowed.

pub fn timer_exists(&self, name: &str) -> bool

Returns whether the timer name exists.

Panics

Panics if the clock is already mutably borrowed.

pub fn next_time_ns(&self, name: &str) -> Option<UnixNanos>

Returns the next trigger timestamp for the timer name.

Panics

Panics if the clock is already mutably borrowed.

pub fn cancel_timer(&self, name: &str)

Cancels the timer name.

Panics

Panics if the clock is already borrowed.

pub fn cancel_timers(&self)

Cancels all timers.

Panics

Panics if the clock is already borrowed.